@@ -52,34 +52,13 @@ function(map)
       
       for(i in 1:length(idx_carte))
       {
-        aa <- lapply(1:length(map$x$calls[[idx_carte[i]]]$args[[1]]), function(x) lapply(c(1:length(map$x$calls[[idx_carte[i]]]$args[[1]][[x]])), function(y) st_polygon(list(as.matrix(map$x$calls[[idx_carte[i]]]$args[[1]][[x]][[y]][[1]])))))
+        fond <- map$x$calls[[idx_carte[i]]]$args[[2]][1][[1]]
+        nom_col <- names(fond)[-which(names(fond)=="geometry")]
+        aa <- map$x$calls[[idx_carte[i]]]$args[[4]]$fillColor
+        fond <- cbind(fond,classe=aa)
+        fond <- fond[,c(nom_col,"classe","geometry")]
         
-        bb <- st_sf(geometry=st_sfc(NULL),crs="+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        for(j in 1:length(aa))
-        {
-          bb <- rbind(bb,st_sf(geometry=st_sfc(st_multipolygon(lapply(1:length(aa[[j]]), function(x) aa[[j]][[x]]))),crs="+init=epsg:4326 +proj=longlat +ellps=WGS84"))
-        }
-        bb <- bb[-1,]
-        
-        if(any(substring(map$x$calls[[idx_carte[i]]]$args[[5]],1,3) %in% "<b>"))
-        {
-          cc <- sapply(1:length(map$x$calls[[idx_carte[i]]]$args[[5]]), function(y) substring(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],25,str_locate_all(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],"<")[[1]][3]-1))
-          fond <- cbind(LIBELLE=cc,bb)
-          dd <- sapply(1:length(map$x$calls[[idx_carte[i]]]$args[[5]]), function(y) substring(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],str_locate_all(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],">")[[1]][11]+1,str_locate_all(map$x$calls[[idx_carte[i]]]$args[[5]][[y]],"<")[[1]][12]-1))
-          dd <- as.numeric(str_replace_all(str_replace_all(dd,",",".")," ",""))
-          fond <- cbind(val=dd,fond)
-          ee <- map$x$calls[[idx_carte[i]]]$args[[4]]$fillColor
-          fond <- cbind(classe=ee,fond)
-          fond$var <- fond$val
-          fond <- fond[,c("LIBELLE","var","val","classe","geometry")]
-          names(fond) <- c("LIBELLE",var_classes,"val","classe","geometry")
-          
-          ff <- lapply(1:length(unique(fond$classe)), function(x) fond[fond$classe %in% rev(unique(fond$classe))[x],"classe"] <<- x)
-          rm(cc,dd,ee,ff)
-        }else
-        {
-          fond <- cbind(LIBELLE=map$x$calls[[idx_carte[i]]]$args[[5]],bb)
-        }
+        bb <- lapply(1:length(unique(fond$classe)), function(x) fond[fond$classe %in% rev(unique(fond$classe))[x],"classe"] <<- x)
         rm(aa,bb)
         
         fond <- st_transform(fond,paste0("+init=epsg:",code_epsg))
