@@ -875,14 +875,12 @@ function(data,fondMaille,fondMailleElargi=NULL,fondContour,fondSuppl=NULL,idData
           m <- leaflet(padding = 0,
                        options = leafletOptions(
                          preferCanvas = TRUE,
-                         transition = 2,
-                         minZoom = 6,
-                         maxZoom = 10
+                         transition = 2
                        )) %>%
             
             setMapWidgetStyle(list(background = "#AFC9E0")) %>%
             
-            addTiles_insee(attribution = paste0("<a href=\"http://www.insee.fr\">\u00A9 IGN - INSEE ",format(Sys.time(), format = "%Y"),"</a>")) %>%
+            addTiles_insee(attribution = paste0("<a href=\"http://www.insee.fr\">OCEANIS - \u00A9 IGN - INSEE ",format(Sys.time(), format = "%Y"),"</a>")) %>%
             
             fitBounds(lng1 = min(list_bbox_rp()[[1]]),
                       lat1 = min(list_bbox_rp()[[2]]),
@@ -918,7 +916,6 @@ function(data,fondMaille,fondMailleElargi=NULL,fondContour,fondSuppl=NULL,idData
                              weight = 1,
                              options = pathOptions(pane = "fond_pays", clickable = F),
                              fill = T, fillColor = "#CCCCCC", fillOpacity = 1
-                             
             )
           }
           
